/*
    DAAC_UIController.h

    Copyright 2008,2009 Josh Freeman
    http://www.twilightedge.com

    This file is part of DAA Converter v1.3 for Mac OS X.

    DAA Converter is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#import <Cocoa/Cocoa.h>


@interface DAAC_UIController : NSObject
{
    IBOutlet NSWindow *_mainWindow;
    IBOutlet NSTextField *_mainWindowConversionStatusTextField;
    IBOutlet NSProgressIndicator *_mainWindowConversionProgressIndicator;
    IBOutlet NSButton *_mainWindowCancelButton;

    IBOutlet NSPanel *_passwordPanel;
    IBOutlet NSTextField *_passwordPanelTextField;
    IBOutlet NSButton *_passwordPanelOKButton;

    IBOutlet id _delegate;

    NSString *_conversionSourceFilename;
    NSString *_conversionTargetFilename;
    unsigned _conversionNumber;
    unsigned _totalNumberOfConversions;

    float _mainWindowFixedHeight;

    int _mainWindowMode;
}

- (IBAction) mainWindowCancelButtonPressed: (id) sender;
- (IBAction) passwordPanelButtonPressed: (id) sender;
- (IBAction) doAboutPanel: (id) sender;

- (void) promptForFilesToConvert;

- (void) promptForPassword;

- (bool) setupForNewConversionWithTargetFilename: (NSString *) targetFilename
                                conversionNumber: (unsigned) conversionNumber;

- (void) updateConversionProgress: (unsigned) completionPercentage;

- (void) updateConversionSourceFilename: (NSString *) sourceFilename;

- (void) updateTotalNumberOfConversions: (unsigned) totalNumConversions;

- (void) displayErrorMessage: (NSString *) errorMessage;

@end


@interface NSObject (DAAC_UIControllerDelegateMethods)

- (void) uiControllerSelectedFilesToConvert: (NSArray *) filepaths;

- (void) uiControllerReceivedPassword: (NSString *) password;

- (void) uiControllerReceivedCancel;

- (void) uiControllerFinishedDisplayingErrorMessage;

- (void) uiControllerNeedsConversionToolCreditsForAboutBox: (NSString **) returnedToolCredits;

@end
